pub fn parse_source_string(source_str: &str) -> Result<PackageRequest>Expand description
Parses a source string into a PackageRequest.
Errors
Returns an error if the source string format is invalid.
pub fn parse_source_string(source_str: &str) -> Result<PackageRequest>Parses a source string into a PackageRequest.
Returns an error if the source string format is invalid.